@@ -68,19 +68,19 @@ class CreateTableModule(CreateFromModule):
 
         return KiaraTable.create_table(imported_data)
 
-    def create__table__from__csv_file(self, source_value: Value) -> Any:
-        """Create a table from a csv_file value."""
-
-        from pyarrow import csv
-
-        input_file: FileModel = source_value.data
-        imported_data = csv.read_csv(input_file.path)
-
-        # import pandas as pd
-        # df = pd.read_csv(input_file.path)
-        # imported_data = pa.Table.from_pandas(df)
-
-        return KiaraTable.create_table(imported_data)
+    # def create__table__from__csv_file(self, source_value: Value) -> Any:
+    #     """Create a table from a csv_file value."""
+    #
+    #     from pyarrow import csv
+    #
+    #     input_file: FileModel = source_value.data
+    #     imported_data = csv.read_csv(input_file.path)
+    #
+    #     # import pandas as pd
+    #     # df = pd.read_csv(input_file.path)
+    #     # imported_data = pa.Table.from_pandas(df)
+    #
+    #     return KiaraTable.create_table(imported_data)
 
     def create__table__from__file_bundle(self, source_value: Value) -> Any:
         """Create a table value from a text file_bundle.
@@ -167,7 +167,7 @@ class DeserializeTableModule(DeserializeValueModule):
         return table
 
 
-class CutColumnModuleConfig(KiaraModuleConfig):
+class PickColumnModuleConfig(KiaraModuleConfig):
     """Configuration for the 'table.cut_column' kiara module.
 
     Technically this is not necessary, because we could just use the 'constants' field to
@@ -180,11 +180,11 @@ class CutColumnModuleConfig(KiaraModuleConfig):
     )
 
 
-class CutColumnModule(KiaraModule):
-    """Cut off one column from a table, returning an array."""
+class PickColumnModule(KiaraModule):
+    """Pick one column from a table, returning an array."""
 
-    _module_type_name = "table.cut_column"
-    _config_cls = CutColumnModuleConfig
+    _module_type_name = "table.pick.column"
+    _config_cls = PickColumnModuleConfig
 
     def create_inputs_schema(
         self,
